@@ -110,6 +110,6 @@ def get_locale_directory_source():
     return os.path.abspath(directory)
 
 CONFIG_HOME_DIR = get_config_home_directory()
-DATA_DIR = '/usr/share/gaupol'
+DATA_DIR = '/gaupol-1.15.data/data/share/gaupol'
 DATA_HOME_DIR = get_data_home_directory()
-LOCALE_DIR = '/usr/share/locale'
+LOCALE_DIR = '/gaupol-1.15.data/data/share/locale'
